pub struct OperationPath(/* private fields */);Expand description
Path to an operation in the local type tree.
A sequence of steps that uniquely identifies an operation.
For example, [Send(0), Branch("Accept"), Recv(0)] identifies
the first receive inside the “Accept” branch after the first send.
Implementations
Sourceimpl OperationPath
impl OperationPath
Sourcepub fn new() -> OperationPath
pub fn new() -> OperationPath
Create an empty path (root).
Sourcepub fn from_steps(steps: Vec<OperationStep>) -> OperationPath
pub fn from_steps(steps: Vec<OperationStep>) -> OperationPath
Create a path from steps.
Sourcepub fn push(&self, step: OperationStep) -> OperationPath
pub fn push(&self, step: OperationStep) -> OperationPath
Append a step to the path, returning a new path.
Sourcepub fn steps(&self) -> &[OperationStep]
pub fn steps(&self) -> &[OperationStep]
Get the steps in this path.