pub struct RoleBoundsChecker { /* private fields */ }Expand description
Runtime bounds checker for dynamic roles.
Implementations
Sourceimpl RoleBoundsChecker
impl RoleBoundsChecker
Sourcepub fn new(max_count: u32, max_index: u32) -> RoleBoundsChecker
pub fn new(max_count: u32, max_index: u32) -> RoleBoundsChecker
Create a new bounds checker with custom limits.
Sourcepub fn check_count(&self, count: u32) -> Result<(), RoleValidationError>
pub fn check_count(&self, count: u32) -> Result<(), RoleValidationError>
Check if a runtime role count is within bounds.
Sourcepub fn check_index(&self, index: u32) -> Result<(), RoleValidationError>
pub fn check_index(&self, index: u32) -> Result<(), RoleValidationError>
Check if a runtime role index is within bounds.
Sourcepub fn check_range(
&self,
start: u32,
end: u32,
) -> Result<(), RoleValidationError>
pub fn check_range( &self, start: u32, end: u32, ) -> Result<(), RoleValidationError>
Check if a runtime range is within bounds.