pub enum HandlerContractTier {
FullProtocol,
ObservationalHarness,
}Expand description
Broad classification of what kind of behavioral surface a handler exposes.
Variants
FullProtocol
A handler that can execute the full typed protocol surface.
ObservationalHarness
A harness that is intentionally observational or partial.