pub trait DocumentedHandlerContract {
// Required method
fn contract_profile() -> HandlerContractProfile
where Self: Sized;
}Expand description
Trait implemented by handlers that document their runtime contract.
pub trait DocumentedHandlerContract {
// Required method
fn contract_profile() -> HandlerContractProfile
where Self: Sized;
}Trait implemented by handlers that document their runtime contract.