pub enum Resource {
Channel(ChannelState),
Message(Message),
Session {
role: String,
type_hash: u64,
},
Value {
tag: String,
data: Vec<u8>,
},
}Expand description
Resource kinds that can be allocated on the heap.
All resources are immutable and content-addressed.
Variants
Channel(ChannelState)
A communication channel between roles
Message(Message)
A message in transit
Session
Current session state for a role
Value
An arbitrary value
Implementations
Sourceimpl Resource
impl Resource
Sourcepub fn channel(sender: impl Into<String>, receiver: impl Into<String>) -> Self
pub fn channel(sender: impl Into<String>, receiver: impl Into<String>) -> Self
Create a channel resource.
Sourcepub fn message(
source: impl Into<String>,
dest: impl Into<String>,
label: impl Into<String>,
payload: Vec<u8>,
seq_no: u64,
) -> Self
pub fn message( source: impl Into<String>, dest: impl Into<String>, label: impl Into<String>, payload: Vec<u8>, seq_no: u64, ) -> Self
Create a message resource.
Sourcepub fn canonical_bytes(&self) -> Vec<u8> ⓘ
pub fn canonical_bytes(&self) -> Vec<u8> ⓘ
Serialize the resource to canonical heap bytes.
The heap derives resource identity and Merkle leaves from this versioned canonical encoding.