Module clock

Module clock 

System clock and RNG for production runtime

These implementations use real system time and entropy sources. For deterministic simulation and testing, use the mock implementations in the testing module instead.

Structs

SystemClock
System clock using real time.
SystemRng
System RNG using host entropy (non-deterministic).