pub struct MessageLenBytes(/* private fields */);Expand description
On-wire message length in bytes.
Implementations
Sourceimpl MessageLenBytes
impl MessageLenBytes
pub const MIN: u32 = 0
pub const MAX: u32 = MAX_MESSAGE_LEN_BYTES
Sourcepub fn new(value: u32) -> Result<MessageLenBytes, CountError>
pub fn new(value: u32) -> Result<MessageLenBytes, CountError>
Create a new value, returning an error if out of range.
Errors
Returns CountError if value is not in MIN..=MAX.
Sourcepub fn try_new(value: u32) -> Result<MessageLenBytes, CountError>
pub fn try_new(value: u32) -> Result<MessageLenBytes, CountError>
Try to create a new value, returning an error if out of range.
Errors
Returns CountError if value is not in MIN..=MAX.
pub const fn get(self) -> u32
pub const fn as_usize(self) -> usize