Module state_machine

Module state_machine 

Protocol state machine for step-by-step simulation

This module provides the core abstraction for simulating protocol execution in a controlled, step-by-step manner.

Structs

Checkpoint
A checkpoint of protocol state for save/restore.
LinearStateMachine
A simple state machine implementation for testing.

Enums

BlockedOn
What a protocol state machine is blocked on.
CheckpointError
Errors that can occur with checkpoints.
StepInput
Input to advance the state machine.
StepOutput
Output from a state machine step.

Traits

ProtocolStateMachine
Trait for protocol state machines that can be stepped through.