pub enum TrySendError<T> {
Full(T),
Closed(T),
}Expand description
Error returned by Sender::try_send.
Variants
Full(T)
The data could not be sent on the channel because the channel is currently full and sending would require blocking.
Closed(T)
The receive half of the channel was explicitly closed or has been dropped.
Implementations
Sourceimpl<T> TrySendError<T>
impl<T> TrySendError<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consume the TrySendError, returning the unsent value.