System clock and RNG for production runtime
These implementations use real system time and entropy sources.
For deterministic simulation and testing, use the mock implementations
in the testing module instead.
Structs
- System
Clock - System clock using real time.
- System
Rng - System RNG using host entropy (non-deterministic).