Protocol state machine for step-by-step simulation
This module provides the core abstraction for simulating protocol execution in a controlled, step-by-step manner.
Structs
- Checkpoint
- A checkpoint of protocol state for save/restore.
- Linear
State Machine - A simple state machine implementation for testing.
Enums
- Blocked
On - What a protocol state machine is blocked on.
- Checkpoint
Error - Errors that can occur with checkpoints.
- Step
Input - Input to advance the state machine.
- Step
Output - Output from a state machine step.
Traits
- Protocol
State Machine - Trait for protocol state machines that can be stepped through.